@@ -130,7 +130,7 @@ class PyPemicro():
 
             lib_info["version"] = dll.version()
             lib_info["version_num"] = dll.get_dll_version()
-        except FileNotFoundError as exc:
+        except (FileNotFoundError, OSError) as exc:
             raise PEMicroException(f"Cannot load the PEMICRO library({lib_name})"+
                                    f"on this path:{dll_path}. Error({str(exc)})")
         return lib_info
@@ -192,8 +192,12 @@ class PyPemicro():
         if file_name is None:
             raise PEMicroException("The libray file name MSUT be specified.")
 
-        # Open the Pemicro library and
-        dll = cdll.LoadLibrary(file_name)
+        try:
+            # Open the Pemicro library and
+            dll = cdll.LoadLibrary(file_name)
+        except (FileNotFoundError, OSError) as exc:
+            raise PEMicroException(f"Cannot load the PEMICRO library({file_name}). "+
+                                   f"Error({str(exc)})")
 
         if dll is None:
             raise PEMicroException("The PEMicro library load failed.")
@@ -1108,20 +1112,24 @@ class PyPemicro():
             raise PEMicroException("Library is not loaded")
         swd_status = self.last_swd_status()
 
-        if swd_status not in [PEMicroSpecialFeaturesSwdStatus.PE_ARM_SWD_STATUS_ACK,
-                              PEMicroSpecialFeaturesSwdStatus.PE_ARM_SWD_STATUS_WAIT]:
-            # Verify that the connection to the P&E hardware interface is good.
-            probe_error = self.lib.check_critical_error()
+        if swd_status is not int(PEMicroSpecialFeaturesSwdStatus.PE_ARM_SWD_STATUS_ACK):
+            if swd_status is not int(PEMicroSpecialFeaturesSwdStatus.PE_ARM_SWD_STATUS_WAIT):
+                # Verify that the connection to the P&E hardware interface is good.
+                probe_error = self.lib.check_critical_error()
 
-            if probe_error & 0x08:
-                # Connect and initialize the P&E hardware interface. This does not attempt to reset the target.
-                self.lib.reset_hardware_interface()
+                if probe_error & 0x08:
+                    # Connect and initialize the P&E hardware interface. This does not attempt to reset the target.
+                    self.lib.reset_hardware_interface()
 
-            self.reset_target()
-            self.halt_target()
+                try:
+                    self.reset_target()
+                except:
+                    self._log_debug("Cannot reset target properly, resume normal state of reset pin.")
+                    self.control_reset_line(assert_reset=False)
+
+                self._log_warning(f"SWD Status failed during IO operation. status: 0x{swd_status:02X},"
+                                f"the communication has been resumed by reset target sequence.")                                
 
-            self._log_warning(f"SWD Status failed during IO operation. status: 0x{swd_status:02X},"
-                              f"the communication has been resumed by reset target sequence.")
             raise PEMicroTransferException(f"SWD Status failed during IO operation. status: 0x{swd_status:02X}")
 
     def write_ap_register(self, apselect: int, addr: int, value: int, now: bool = False) -> None:
